RouteGenerator class

A class to generate routes with optional hash-based routing.

Constructors

RouteGenerator({bool? useHashRouting})
Creates a RouteGenerator instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
useHashRouting bool?
If true, use hash routing (e.g. '/#/page'), otherwise use path routing ('/page'). Nullable to allow unspecified behavior.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited