payfast_web library
Classes
- AnimatedSwitcherWidget
- A utility class to provide customizable configurations for an AnimatedSwitcher.
- PayFast
-
The
PayFastclass is a stateful widget designed to integrate PayFast's payment processing system into a Flutter web application. - RouteGenerator
- A class to generate routes with optional hash-based routing.